package org.firstinspires.ftc.teamcode.runmodes;

import com.qualcomm.robotcore.hardware.HardwareMap;

import org.firstinspires.ftc.robotcore.external.Telemetry;
import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.BezierCurve;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.BezierLine;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.Path;
import org.firstinspires.ftc.teamcode.pedroPathing.localization.Pose;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.Point;
import org.firstinspires.ftc.teamcode.pedroPathing.util.Timer;
import org.firstinspires.ftc.teamcode.subsystem.ArmSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.ClawSubsystem;
import static org.firstinspires.ftc.teamcode.util.action.FieldConstants.*;

import org.firstinspires.ftc.teamcode.subsystem.WristSubsystem;
import org.firstinspires.ftc.teamcode.util.action.Action;
import org.firstinspires.ftc.teamcode.util.action.RunAction;
import org.firstinspires.ftc.teamcode.util.action.SequentialAction;
import org.firstinspires.ftc.teamcode.util.action.SleepAction;

public class Auto {

    public ClawSubsystem claw;
    public ArmSubsystem arm;
    public WristSubsystem wrist;

    public Timer clawTimer = new Timer();
    public Timer armTimer = new Timer();
    public Timer wristTimer = new Timer();

    public Follower follower;
    public Telemetry telemetry;

    public Auto(HardwareMap hardwareMap, Telemetry telemetry, Follower follower) {
        claw = new ClawSubsystem(hardwareMap, ClawSubsystem.ClawState.CLOSED);
        arm = new ArmSubsystem(hardwareMap, ArmSubsystem.ArmState.PARK);
        wrist = new WristSubsystem(hardwareMap, WristSubsystem.WristState.FLOOR);

        this.follower = follower;
        this.telemetry = telemetry;

        init();
    }

    public void init() {
        claw.init();
        arm.init();
        wrist.init();
    }

    public void start() {
        clawTimer.resetTimer();
        armTimer.resetTimer();
        wristTimer.resetTimer();

        claw.start();
        arm.start();
        wrist.start();
    }

    public void update() {
        //follower.update();
        if (clawTimer.getElapsedTimeSeconds() > 2) {
            claw.openClaw();
        }
        if (armTimer.getElapsedTimeSeconds() > 4) {
            arm.engageArm();
        }
        if (clawTimer.getElapsedTimeSeconds() > 6) {
            claw.closeClaw();
        }
        if (armTimer.getElapsedTimeSeconds() > 8) {
            arm.bucketArm();
            wrist.bucketWrist();
        }
        if (clawTimer.getElapsedTimeSeconds() > 10) {
            claw.openClaw();
        }
    }

}
